@@ -113,14 +113,14 @@ void to::test<1>()
 	InputMerger<string, string> result;
 	TestFilter filter(result);
 
-	ensure(filter.isComplete());
+	gen_ensure(filter.isComplete());
 
 	outputCollection(input_coll, filter); 
 
 	InputMerger<string, string> reference;
 	outputCollection(output_coll, reference); 
 
-	ensure_coll_equal(reference, result);
+	gen_ensure_coll_equals(reference, result);
 }
 
 template<> template<>
@@ -144,23 +144,23 @@ void to::test<2>()
 	TestFilter filter1;
 	TestFilter filter2("add2");
 
-	ensure(!filter1.isComplete());
-	ensure(!filter2.isComplete());
+	gen_ensure(!filter1.isComplete());
+	gen_ensure(!filter2.isComplete());
 
 	chain.appendFilter(filter1);
 	chain.setConsumer(result);
 	chain.appendFilter(filter2);
 
-	ensure_equals(&(chain.getConsumer()), &filter1);
-	ensure_equals(&(filter1.getConsumer()), &filter2);
-	ensure_equals(&(filter2.getConsumer()), &result);
+	gen_ensure_equals(&(chain.getConsumer()), &filter1);
+	gen_ensure_equals(&(filter1.getConsumer()), &filter2);
+	gen_ensure_equals(&(filter2.getConsumer()), &result);
 
 	outputCollection(input_coll, chain); 
 
 	InputMerger<string, string> reference;
 	outputCollection(output_coll, reference); 
 
-	ensure_coll_equal(reference, result);
+	gen_ensure_coll_equals(reference, result);
 }
 
 }
