@@ -60,7 +60,6 @@ OpSet<TAG> PatchCollection<ITEM, TAG>::getTagsOfItem(const ITEM& item) const
 	return changes.patch(item, coll.getTags(item));
 }
 
-
 template<class ITEM, class TAG>
 void PatchCollection<ITEM, TAG>::setChanges(const PatchList<ITEM, TAG>& changes)
 {
@@ -83,6 +82,16 @@ void PatchCollection<ITEM, TAG>::setChanges(const PatchList<ITEM, TAG>& changes)
 		}
 }
 
+template<class ITEM, class TAG>
+void PatchCollection<ITEM, TAG>::addChanges(const PatchList<ITEM, TAG>& changes)
+{
+	PatchList<ITEM, TAG> ch(this->changes);
+
+	ch.addPatch(changes);
+
+	setChanges(ch);
+}
+
 template<class ITEM, class TAG>
 bool PatchCollection<ITEM, TAG>::hasTag(const TAG& tag) const
 {
@@ -118,14 +127,14 @@ template<typename ITEM, typename TAG>
 class TagCollector : public Consumer<ITEM, TAG>, public OpSet<TAG>
 {
 protected:
-	virtual void consumeItemUntagged(const ITEM& item) {}
-	virtual void consumeItemsUntagged(const OpSet<ITEM>& item) {}
+	virtual void consumeItemUntagged(const ITEM&) {}
+	virtual void consumeItemsUntagged(const OpSet<ITEM>&) {}
 
-	virtual void consumeItem(const ITEM& item, const OpSet<TAG>& tags)
+	virtual void consumeItem(const ITEM&, const OpSet<TAG>& tags)
 	{
 		*this += tags;
 	}
-	virtual void consumeItems(const OpSet<ITEM>& items, const OpSet<TAG>& tags)
+	virtual void consumeItems(const OpSet<ITEM>&, const OpSet<TAG>& tags)
 	{
 		*this += tags;
 	}
@@ -234,7 +243,19 @@ void to::test<1>()
 
 	PatchCollection<string, string> coll(startcoll);
 
-	test_tagged_collection(coll);
+	output_test_collection(coll);
+	test_readonly_collection(coll);
+}
+
+template<> template<>
+void to::test<2>()
+{
+	// Use an InputMerger as the embedded collection
+	InputMerger<string, string> startcoll;
+
+	PatchCollection<string, string> coll(startcoll);
+
+	test_collection(coll);
 }
 
 }
