@@ -12,7 +12,7 @@ int main (int argc, char *argv[])
 	try {
 		// Install the handler for unexpected exceptions
 		InstallUnexpected installUnexpected;
-		Converter<string, string> conv;
+		TrivialConverter<string, string> conv;
 		TDBReadonlyDiskIndex<string, string> coll(
 				argv[1], argv[2],
 				conv, conv, conv, conv);
