@@ -15,7 +15,7 @@ int main (int argc, char *argv[])
 	try {
 		// Install the handler for unexpected exceptions
 		InstallUnexpected installUnexpected;
-		Converter<string, string> conv;
+		TrivialConverter<string, string> conv;
 		Graph<string, string> graph;
 		StdioParserInput in(stdin, "(stdin)");
 
