@@ -13,7 +13,7 @@ int main (int argc, char *argv[])
 	try {
 		// Install the handler for unexpected exceptions
 		InstallUnexpected installUnexpected;
-		Converter<string, string> conv;
+		TrivialConverter<string, string> conv;
 		Normalizer<string, string> norm(1.0);
 		StdioParserInput in(stdin, "(stdin)");
 
